@@ -10,8 +10,10 @@ use base qw( Log::Dispatch::Output );
 use Params::Validate qw(validate SCALAR ARRAYREF BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
-our $VERSION = '1.19';
+our $VERSION = '2.23';
 
+# need to untaint this value
+my ($program) = $0 =~ /(.+)/;
 
 sub new
 {
@@ -19,13 +21,13 @@ sub new
     my $class = ref $proto || $proto;
 
     my %p = validate( @_, { subject  => { type => SCALAR,
-					  default => "$0: log email" },
-			    to       => { type => SCALAR | ARRAYREF },
-			    from     => { type => SCALAR,
-					  optional => 1 },
-			    buffered => { type => BOOLEAN,
-					  default => 1 },
-			  } );
+                                          default => "$program: log email" },
+                            to       => { type => SCALAR | ARRAYREF },
+                            from     => { type => SCALAR,
+                                          optional => 1 },
+                            buffered => { type => BOOLEAN,
+                                          default => 1 },
+                          } );
 
     my $self = bless {}, $class;
 
@@ -50,11 +52,11 @@ sub log_message
 
     if ($self->{buffered})
     {
-	push @{ $self->{buffer} }, $p{message};
+        push @{ $self->{buffer} }, $p{message};
     }
     else
     {
-	$self->send_email(@_);
+        $self->send_email(@_);
     }
 }
 
@@ -72,9 +74,9 @@ sub flush
 
     if ($self->{buffered} && @{ $self->{buffer} })
     {
-	my $message = join '', @{ $self->{buffer} };
+        my $message = join '', @{ $self->{buffer} };
 
-	$self->send_email( message => $message );
+        $self->send_email( message => $message );
         $self->{buffer} = [];
     }
 }
@@ -118,33 +120,13 @@ Log::Dispatch::* objects that send their log messages via email.
 Implementing a subclass simply requires the code shown in the
 L<SYNOPSIS> with a real implementation of the C<send_email()> method.
 
-=head1 METHODS
+=head1 CONSTRUCTOR
+
+The constructor takes the following parameters in addition to the standard
+parameters documented in L<Log::Dispatch::Output>:
 
 =over 4
 
-=item * new(%p)
-
-This method takes a hash of parameters.  The following options are
-valid:
-
-=over 8
-
-=item * name ($)
-
-The name of the object (not the filename!).  Required.
-
-=item * min_level ($)
-
-The minimum logging level this object will accept.  See the
-Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
-
-=item * max_level ($)
-
-The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
-required.  By default the maximum is the highest possible level (which
-means functionally that the object has no maximum).
-
 =item * subject ($)
 
 The subject of the email messages which are sent.  Defaults to "$0:
@@ -166,26 +148,11 @@ This determines whether the object sends one email per message it is
 given or whether it stores them up and sends them all at once.  The
 default is to buffer messages.
 
-=item * callbacks( \& or [ \&, \&, ... ] )
-
-This parameter may be a single subroutine reference or an array
-reference of subroutine references.  These callbacks will be called in
-the order they are given and passed a hash containing the following keys:
-
- ( message => $log_message, level => $log_level )
-
-The callbacks are expected to modify the message and then return a
-single scalar containing that modified message.  These callbacks will
-be called when either the C<log> or C<log_to> methods are called and
-will only be applied to a given message once.
-
 =back
 
-=item * log_message( message => $ )
+=head1 METHODS
 
-Sends a message to the appropriate output.  Generally this shouldn't
-be called directly but should be called through the C<log()> method
-(in Log::Dispatch::Output).
+=over 4
 
 =item * send_email(%p)
 
