@@ -10,7 +10,7 @@ use base qw( Log::Dispatch::Output );
 use Params::Validate qw(validate SCALAR BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
 
-our $VERSION = '1.22';
+our $VERSION = '2.23';
 
 # Prevents death later on if IO::File can't export this constant.
 *O_APPEND = \&APPEND unless defined &O_APPEND;
@@ -158,47 +158,37 @@ Log::Dispatch::File - Object for logging to files
 
 =head1 SYNOPSIS
 
-  use Log::Dispatch::File;
+  use Log::Dispatch;
 
-  my $file = Log::Dispatch::File->new( name      => 'file1',
-                                       min_level => 'info',
-                                       filename  => 'Somefile.log',
-                                       mode      => 'append' );
+  my $log =
+      Log::Dispatch->new
+          ( outputs =>
+            [ 'File' =>
+                  { min_level => 'info',
+                    filename  => 'Somefile.log',
+                    mode      => '>>',
+                    newline   => 1,
+                  },
+            ],
+          );
 
-  $file->log( level => 'emerg', message => "I've fallen and I can't get up\n" );
+  $log->emerg("I've fallen and I can't get up");
 
 =head1 DESCRIPTION
 
 This module provides a simple object for logging to files under the
 Log::Dispatch::* system.
 
-=head1 METHODS
+Note that a newline will I<not> be added automatically at the end of a message
+by default.  To do that, pass C<< newline => 1 >>.
+
+=head1 CONSTRUCTOR
+
+The constructor takes the following parameters in addition to the standard
+parameters documented in L<Log::Dispatch::Output>:
 
 =over 4
 
-=item * new(%p)
-
-This method takes a hash of parameters.  The following options are
-valid:
-
-=over 8
-
-=item * name ($)
-
-The name of the object (not the filename!).  Required.
-
-=item * min_level ($)
-
-The minimum logging level this object will accept.  See the
-Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
-
-=item * max_level ($)
-
-The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
-required.  By default the maximum is the highest possible level (which
-means functionally that the object has no maximum).
-
 =item * filename ($)
 
 The filename to be opened for writing.
@@ -244,27 +234,6 @@ Then the resulting file will end up with permissions like this:
 
 which is probably not what you want.
 
-=item * callbacks( \& or [ \&, \&, ... ] )
-
-This parameter may be a single subroutine reference or an array
-reference of subroutine references.  These callbacks will be called in
-the order they are given and passed a hash containing the following keys:
-
- ( message => $log_message, level => $log_level )
-
-The callbacks are expected to modify the message and then return a
-single scalar containing that modified message.  These callbacks will
-be called when either the C<log> or C<log_to> methods are called and
-will only be applied to a given message once.
-
-=back
-
-=item * log_message( message => $ )
-
-Sends a message to the appropriate output.  Generally this shouldn't
-be called directly but should be called through the C<log()> method
-(in Log::Dispatch::Output).
-
 =back
 
 =head1 AUTHOR
