@@ -12,7 +12,7 @@ Params::Validate::validation_options( allow_extra => 1 );
 
 use Sys::Syslog 0.16 ();
 
-our $VERSION = '1.18';
+our $VERSION = '2.23';
 
 sub new
 {
@@ -89,13 +89,20 @@ Log::Dispatch::Syslog - Object for logging to system log.
 
 =head1 SYNOPSIS
 
-  use Log::Dispatch::Syslog;
+  use Log::Dispatch;
 
-  my $file = Log::Dispatch::Syslog->new( name      => 'file1',
-                                         min_level => 'info',
-                                         ident     => 'Yadda yadda' );
+  my $log =
+      Log::Dispatch->new
+          ( outputs =>
+            [ 'Syslog' =>
+                  { min_level => 'info',
+                    ident => 'Yadda yadda'
+                  },
+            ],
+          );
+  my $log = Log::Dispatch->new( outputs => [Syslog => {  }]);
 
-  $file->log( level => 'emerg', message => "Time to die." );
+  $log->emerg( "Time to die." );
 
 =head1 DESCRIPTION
 
@@ -106,33 +113,13 @@ Note that logging may fail if you try to pass UTF-8 characters in the
 log message. If logging fails and warnings are enabled, the error
 message will be output using Perl's C<warn>.
 
-=head1 METHODS
+=head1 CONSTRUCTOR
+
+The constructor takes the following parameters in addition to the standard
+parameters documented in L<Log::Dispatch::Output>:
 
 =over 4
 
-=item * new(%p)
-
-This method takes a hash of parameters.  The following options are
-valid:
-
-=over 8
-
-=item * name ($)
-
-The name of the object.  Required.
-
-=item * min_level ($)
-
-The minimum logging level this object will accept.  See the
-Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
-
-=item * max_level ($)
-
-The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
-required.  By default the maximum is the highest possible level (which
-means functionally that the object has no maximum).
-
 =item * ident ($)
 
 This string will be prepended to all messages in the system log.
@@ -160,27 +147,6 @@ If you don't provide this, then we let C<Sys::Syslog> simply pick one
 that works, which is the preferred option, as it makes your code more
 portable.
 
-=item * callbacks( \& or [ \&, \&, ... ] )
-
-This parameter may be a single subroutine reference or an array
-reference of subroutine references.  These callbacks will be called in
-the order they are given and passed a hash containing the following keys:
-
- ( message => $log_message, level => $log_level )
-
-The callbacks are expected to modify the message and then return a
-single scalar containing that modified message.  These callbacks will
-be called when either the C<log> or C<log_to> methods are called and
-will only be applied to a given message once.
-
-=back
-
-=item * log_message( message => $ )
-
-Sends a message to the appropriate output.  Generally this shouldn't
-be called directly but should be called through the C<log()> method
-(in Log::Dispatch::Output).
-
 =back
 
 =head1 AUTHOR
